pub struct MenuColumn<'a, Message, Renderer = Renderer> { /* private fields */ }Implementations
Sourceimpl<'a, Message, Renderer> MenuColumn<'a, Message, Renderer>where
Renderer: Renderer,
impl<'a, Message, Renderer> MenuColumn<'a, Message, Renderer>where
Renderer: Renderer,
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates an empty MenuColumn.
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates a MenuColumn with the given capacity.
Sourcepub fn with_children(
children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>,
) -> Self
pub fn with_children( children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>, ) -> Self
Creates a MenuColumn with the given elements.
Sourcepub fn from_vec(children: Vec<Element<'a, Message, Theme, Renderer>>) -> Self
pub fn from_vec(children: Vec<Element<'a, Message, Theme, Renderer>>) -> Self
Creates a MenuColumn from an already allocated Vec.
Keep in mind that the MenuColumn will not inspect the Vec, which means
it won’t automatically adapt to the sizing strategy of its contents.
If any of the children have a Length::Fill strategy, you will need to
call MenuColumn::width or MenuColumn::height accordingly.
Sourcepub fn spacing(self, amount: impl Into<Pixels>) -> Self
pub fn spacing(self, amount: impl Into<Pixels>) -> Self
Sets the vertical spacing between elements.
Custom margins per element do not exist in iced. You should use this method instead! While less flexible, it helps you keep spacing between elements consistent.
Sourcepub fn width(self, width: impl Into<Length>) -> Self
pub fn width(self, width: impl Into<Length>) -> Self
Sets the width of the MenuColumn.
Sourcepub fn height(self, height: impl Into<Length>) -> Self
pub fn height(self, height: impl Into<Length>) -> Self
Sets the height of the MenuColumn.
Sourcepub fn max_width(self, max_width: impl Into<Pixels>) -> Self
pub fn max_width(self, max_width: impl Into<Pixels>) -> Self
Sets the maximum width of the MenuColumn.
Sourcepub fn align_x(self, align: impl Into<Horizontal>) -> Self
pub fn align_x(self, align: impl Into<Horizontal>) -> Self
Sets the horizontal alignment of the contents of the MenuColumn .
Sourcepub fn clip(self, clip: bool) -> Self
pub fn clip(self, clip: bool) -> Self
Sets whether the contents of the MenuColumn should be clipped on
overflow.
Sourcepub fn push(
self,
child: impl Into<Element<'a, Message, Theme, Renderer>>,
) -> Self
pub fn push( self, child: impl Into<Element<'a, Message, Theme, Renderer>>, ) -> Self
Adds an element to the MenuColumn.
Sourcepub fn push_maybe(
self,
child: Option<impl Into<Element<'a, Message, Theme, Renderer>>>,
) -> Self
pub fn push_maybe( self, child: Option<impl Into<Element<'a, Message, Theme, Renderer>>>, ) -> Self
Adds an element to the MenuColumn, if Some.
Sourcepub fn extend(
self,
children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>,
) -> Self
pub fn extend( self, children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>, ) -> Self
Extends the MenuColumn with the given children.